[llvm-commits] CVS: llvm/include/llvm/CodeGen/DwarfWriter.h MachineFrameInfo.h MachineFunction.h ScheduleDAG.h SelectionDAG.h SelectionDAGNodes.h

Jim Laskey jlaskey at apple.com
Fri Jan 26 13:23:04 PST 2007



Changes in directory llvm/include/llvm/CodeGen:

DwarfWriter.h updated: 1.43 -> 1.44
MachineFrameInfo.h updated: 1.21 -> 1.22
MachineFunction.h updated: 1.63 -> 1.64
ScheduleDAG.h updated: 1.33 -> 1.34
SelectionDAG.h updated: 1.145 -> 1.146
SelectionDAGNodes.h updated: 1.164 -> 1.165
---
Log message:

Change the MachineDebugInfo to MachineModuleInfo to better reflect usage
for debugging and exception handling.


---
Diffs of the changes:  (+23 -23)

 DwarfWriter.h       |   10 +++++-----
 MachineFrameInfo.h  |   20 ++++++++++----------
 MachineFunction.h   |    2 +-
 ScheduleDAG.h       |    2 +-
 SelectionDAG.h      |   10 +++++-----
 SelectionDAGNodes.h |    2 +-
 6 files changed, 23 insertions(+), 23 deletions(-)


Index: llvm/include/llvm/CodeGen/MachineFunction.h
diff -u llvm/include/llvm/CodeGen/MachineFunction.h:1.63 llvm/include/llvm/CodeGen/MachineFunction.h:1.64
--- llvm/include/llvm/CodeGen/MachineFunction.h:1.63	Sat Dec 16 23:15:12 2006
+++ llvm/include/llvm/CodeGen/MachineFunction.h	Fri Jan 26 15:22:27 2007
@@ -18,7 +18,7 @@
 #ifndef LLVM_CODEGEN_MACHINEFUNCTION_H
 #define LLVM_CODEGEN_MACHINEFUNCTION_H
 
-#include "llvm/CodeGen/MachineDebugInfo.h"
+#include "llvm/CodeGen/MachineModuleInfo.h"
 #include "llvm/CodeGen/MachineBasicBlock.h"
 #include "llvm/Support/Annotation.h"
 


Index: llvm/include/llvm/CodeGen/ScheduleDAG.h
diff -u llvm/include/llvm/CodeGen/ScheduleDAG.h:1.33 llvm/include/llvm/CodeGen/ScheduleDAG.h:1.34
--- llvm/include/llvm/CodeGen/ScheduleDAG.h:1.33	Sat Nov  4 03:42:53 2006
+++ llvm/include/llvm/CodeGen/ScheduleDAG.h	Fri Jan 26 15:22:28 2007
@@ -22,7 +22,7 @@
 namespace llvm {
   struct InstrStage;
   class MachineConstantPool;
-  class MachineDebugInfo;
+  class MachineModuleInfo;
   class MachineInstr;
   class MRegisterInfo;
   class SelectionDAG;


Index: llvm/include/llvm/CodeGen/SelectionDAG.h
diff -u llvm/include/llvm/CodeGen/SelectionDAG.h:1.145 llvm/include/llvm/CodeGen/SelectionDAG.h:1.146
--- llvm/include/llvm/CodeGen/SelectionDAG.h:1.145	Thu Nov  9 11:53:01 2006
+++ llvm/include/llvm/CodeGen/SelectionDAG.h	Fri Jan 26 15:22:28 2007
@@ -29,7 +29,7 @@
   class AliasAnalysis;
   class TargetLowering;
   class TargetMachine;
-  class MachineDebugInfo;
+  class MachineModuleInfo;
   class MachineFunction;
   class MachineConstantPoolValue;
 
@@ -47,7 +47,7 @@
 class SelectionDAG {
   TargetLowering &TLI;
   MachineFunction &MF;
-  MachineDebugInfo *DI;
+  MachineModuleInfo *MMI;
 
   /// Root - The root of the entire DAG.  EntryNode - The starting token.
   SDOperand Root, EntryNode;
@@ -60,8 +60,8 @@
   FoldingSet<SDNode> CSEMap;
 
 public:
-  SelectionDAG(TargetLowering &tli, MachineFunction &mf, MachineDebugInfo *di)
-  : TLI(tli), MF(mf), DI(di) {
+  SelectionDAG(TargetLowering &tli, MachineFunction &mf, MachineModuleInfo *mmi)
+  : TLI(tli), MF(mf), MMI(mmi) {
     EntryNode = Root = getNode(ISD::EntryToken, MVT::Other);
   }
   ~SelectionDAG();
@@ -69,7 +69,7 @@
   MachineFunction &getMachineFunction() const { return MF; }
   const TargetMachine &getTarget() const;
   TargetLowering &getTargetLoweringInfo() const { return TLI; }
-  MachineDebugInfo *getMachineDebugInfo() const { return DI; }
+  MachineModuleInfo *getMachineModuleInfo() const { return MMI; }
 
   /// viewGraph - Pop up a GraphViz/gv window with the DAG rendered using 'dot'.
   ///


Index: llvm/include/llvm/CodeGen/SelectionDAGNodes.h
diff -u llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.164 llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.165
--- llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.164	Fri Jan 26 08:34:51 2007
+++ llvm/include/llvm/CodeGen/SelectionDAGNodes.h	Fri Jan 26 15:22:28 2007
@@ -506,7 +506,7 @@
     
     // DEBUG_LOC - This node is used to represent source line information
     // embedded in the code.  It takes a token chain as input, then a line
-    // number, then a column then a file id (provided by MachineDebugInfo.) It
+    // number, then a column then a file id (provided by MachineModuleInfo.) It
     // produces a token chain as output.
     DEBUG_LOC,
     






More information about the llvm-commits mailing list
Index: llvm/include/llvm/CodeGen/DwarfWriter.h
diff -u llvm/include/llvm/CodeGen/DwarfWriter.h:1.43 llvm/include/llvm/CodeGen/DwarfWriter.h:1.44
--- llvm/include/llvm/CodeGen/DwarfWriter.h:1.43	Thu Dec  7 14:28:15 2006
+++ llvm/include/llvm/CodeGen/DwarfWriter.h	Fri Jan 26 15:22:27 2007
@@ -12,7 +12,7 @@
 // V.3 reference manual http://dwarf.freestandards.org ,
 //
 // The role of the Dwarf Writer class is to extract debug information from the
 // MachineDebugInfo object, organize it in Dwarf form and then emit it into asm
 // the current asm file using data and high level Dwarf directives.
 // 
 //===----------------------------------------------------------------------===//
@@ -26,7 +26,7 @@
 
 class AsmPrinter;
 class Dwarf;
-class MachineDebugInfo;
+class MachineModuleInfo;
 class MachineFunction;
 class Module;
 class TargetAsmInfo;
@@ -46,9 +46,9 @@
   DwarfWriter(std::ostream &OS, AsmPrinter *A, const TargetAsmInfo *T);
   virtual ~DwarfWriter();
   
-  /// SetDebugInfo - Set DebugInfo when it's known that pass manager has
-  /// created it.  Set by the target AsmPrinter.
-  void SetDebugInfo(MachineDebugInfo *DI);
+  /// SetModuleInfo - Set machine module info when it's known that pass manager
+  /// has created it.  Set by the target AsmPrinter.
+  void SetModuleInfo(MachineModuleInfo *MMI);
 
   //===--------------------------------------------------------------------===//
   // Main entry points.
@@ -12,7 +12,7 @@
 //
 // The role of the Dwarf Writer class is to extract debug information from the
-// MachineDebugInfo object, organize it in Dwarf form and then emit it into asm
+// MachineModuleInfo object, organize it in Dwarf form and then emit it into asm
 // the current asm file using data and high level Dwarf directives.
 // 


Index: llvm/include/llvm/CodeGen/MachineFrameInfo.h
diff -u llvm/include/llvm/CodeGen/MachineFrameInfo.h:1.21 llvm/include/llvm/CodeGen/MachineFrameInfo.h:1.22
--- llvm/include/llvm/CodeGen/MachineFrameInfo.h:1.21	Fri Nov 17 15:19:15 2006
+++ llvm/include/llvm/CodeGen/MachineFrameInfo.h	Fri Jan 26 15:22:27 2007
@@ -17,7 +17,7 @@
 class TargetData;
 class TargetRegisterClass;
 class Type;
-class MachineDebugInfo;
+class MachineModuleInfo;
 class MachineFunction;
 
 /// The CalleeSavedInfo class tracks the information need to locate where a
@@ -147,12 +147,12 @@
   /// handling.
   std::vector<CalleeSavedInfo> CSInfo;
   
   /// DebugInfo - This field is set (via setMachineDebugInfo) by a debug info
   /// consumer (ex. DwarfWriter) to indicate that frame layout information
   /// should be acquired.  Typically, it's the responsibility of the target's
   /// MRegisterInfo prologue/epilogue emitting code to inform MachineDebugInfo
   /// of frame layouts.
-  MachineDebugInfo *DebugInfo;
+  MachineModuleInfo *MMI;
   
 public:
   MachineFrameInfo() {
@@ -160,7 +160,7 @@
     HasVarSizedObjects = false;
     HasCalls = false;
     MaxCallFrameSize = 0;
-    DebugInfo = 0;
+    MMI = 0;
   }
 
   /// hasStackObjects - Return true if there are any stack objects in this
@@ -299,13 +299,13 @@
     CSInfo = CSI;
   }
 
   /// getMachineDebugInfo - Used by a prologue/epilogue emitter (MRegisterInfo)
   /// to provide frame layout information. 
-  MachineDebugInfo *getMachineDebugInfo() const { return DebugInfo; }
+  MachineModuleInfo *getMachineModuleInfo() const { return MMI; }
 
-  /// setMachineDebugInfo - Used by a debug consumer (DwarfWriter) to indicate
-  /// that frame layout information should be gathered.
-  void setMachineDebugInfo(MachineDebugInfo *DI) { DebugInfo = DI; }
+  /// setMachineModuleInfo - Used by a meta info consumer (DwarfWriter) to
+  /// indicate that frame layout information should be gathered.
+  void setMachineModuleInfo(MachineModuleInfo *mmi) { MMI = mmi; }
 
   /// print - Used by the MachineFunction printer to print information about
   /// stack objects.  Implemented in MachineFunction.cpp
@@ -147,12 +147,12 @@
   std::vector<CalleeSavedInfo> CSInfo;
   
-  /// DebugInfo - This field is set (via setMachineDebugInfo) by a debug info
+  /// MMI - This field is set (via setMachineModuleInfo) by a module info
   /// consumer (ex. DwarfWriter) to indicate that frame layout information
   /// should be acquired.  Typically, it's the responsibility of the target's
@@ -147,12 +147,12 @@
   /// consumer (ex. DwarfWriter) to indicate that frame layout information
   /// should be acquired.  Typically, it's the responsibility of the target's
-  /// MRegisterInfo prologue/epilogue emitting code to inform MachineDebugInfo
+  /// MRegisterInfo prologue/epilogue emitting code to inform MachineModuleInfo
   /// of frame layouts.
@@ -299,13 +299,13 @@
   }
 
-  /// getMachineDebugInfo - Used by a prologue/epilogue emitter (MRegisterInfo)
+  /// getMachineModuleInfo - Used by a prologue/epilogue emitter (MRegisterInfo)
   /// to provide frame layout information. 

